Worldwide_Pollution-class: Title Worldwide_Pollution

Description Fields

Description

This class creates one object which can give access in an API.The user can choose between four countries(Greece,Italy,Sweden,Turkey), and manipulate data for air pollution such as value pm5.

Fields

responses

list. The list of responses comming from API

root_url

character. The base url of the API

countries

list. A list of the user's input


Sburanga/Adv_Progr_5 documentation built on May 23, 2019, 6:02 p.m.