This class creates one object which can give access in an API.The user can choose between four countries(Greece,Italy,Sweden,Turkey), and manipulate data for air pollution such as value pm5.
responseslist. The list of responses comming from API
root_urlcharacter. The base url of the API
countrieslist. A list of the user's input
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.